@@ -55,7 +55,7 @@ def format_email_and_url(text):
     email=re.compile('"([\w\-\.]+@[\w\-\.]+)"')
     result=email.sub(r'\1',result);
 
-    url=re.compile('"http://([\w\-\./]+)"', re.I)
+    url=re.compile('"http://([\w\-\.\~/]+)"', re.I)
     result=url.sub(r'http://\1',result);
 
     return result
@@ -78,7 +78,7 @@ def format_html(text):
     email=re.compile('"([\w\-\.]+@[\w\-\.]+)"')
     result=email.sub(r'<A HREF="mailto:\1">\1</A>',result);
 
-    url=re.compile('"http://([\w\-\./]+)"', re.I)
+    url=re.compile('"http://([\w\-\.\~/]+)"', re.I)
     result=url.sub(r'<A HREF="http://\1">\1</A>',result);
     
     return result
