@@ -120,6 +120,7 @@
 #define LABEL_PASSWORD "PASSWORD"
 #define LABEL_MIN_MAP_RES "MIN_MAP_RES"
 #define LABEL_USE_DEFAULT_TEXTURE "USE_DEFAULT_TEXTURE"
+#define LABEL_ALLOW_NETWORK_BOTS "ALLOW_NETWORK_BOTS"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -167,6 +168,7 @@ int CONFIG_ASM_ALGORITHM;
 char CONFIG_PASSWORD[PASSWORD_SIZE + 1];
 int CONFIG_MIN_MAP_RES;
 int CONFIG_USE_DEFAULT_TEXTURE;
+int CONFIG_ALLOW_NETWORK_BOTS;
 
 LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
@@ -309,6 +311,7 @@ load_default_rules (void)
   CONFIG_CPU_VS_HUMAN = CONFIG_CPU_VS_HUMAN_RANDOM;
   CONFIG_ASM_ALGORITHM = 1;
   CONFIG_MIN_MAP_RES = 4;
+  CONFIG_ALLOW_NETWORK_BOTS = 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -465,6 +468,9 @@ load_disk_options (void)
       CONFIG_USE_DEFAULT_TEXTURE =
 	get_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
 			CONFIG_USE_DEFAULT_TEXTURE);
+      CONFIG_ALLOW_NETWORK_BOTS =
+	get_config_int (LABEL_MAIN, LABEL_ALLOW_NETWORK_BOTS,
+			CONFIG_ALLOW_NETWORK_BOTS);
 
       return 1;
     }
@@ -579,6 +585,8 @@ save_config_options (void)
   set_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
   set_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
 		  CONFIG_USE_DEFAULT_TEXTURE);
+  set_config_int (LABEL_MAIN, LABEL_ALLOW_NETWORK_BOTS,
+		  CONFIG_ALLOW_NETWORK_BOTS);
 
   return 0;
 }
