@@ -158,131 +158,134 @@
 #define LW_LANG_STRING_ADVANCED_RANDOM            69
 #define LW_LANG_STRING_ADVANCED_NEVER             70
 #define LW_LANG_STRING_ADVANCED_ASMALGORITHM      71
-#define LW_LANG_STRING_ADVANCED_YES               72
-#define LW_LANG_STRING_ADVANCED_NO                73
+#define LW_LANG_STRING_ADVANCED_ASSEMBLY          72
+#define LW_LANG_STRING_ADVANCED_STANDARDC         73
+#define LW_LANG_STRING_ADVANCED_ALLOWNETWORKBOTS  74
+#define LW_LANG_STRING_ADVANCED_YES               75
+#define LW_LANG_STRING_ADVANCED_NO                76
 
-#define LW_LANG_STRING_SPEEDS_FPS                 74
-#define LW_LANG_STRING_SPEEDS_NOFPSLIMIT          75
-#define LW_LANG_STRING_SPEEDS_RPS                 76
-#define LW_LANG_STRING_SPEEDS_NORPSLIMIT          77
+#define LW_LANG_STRING_SPEEDS_FPS                 77
+#define LW_LANG_STRING_SPEEDS_NOFPSLIMIT          78
+#define LW_LANG_STRING_SPEEDS_RPS                 79
+#define LW_LANG_STRING_SPEEDS_NORPSLIMIT          80
 
-#define LW_LANG_STRING_CONTROLS_JOYSTICK          78
-#define LW_LANG_STRING_CONTROLS_OFF               79
-#define LW_LANG_STRING_CONTROLS_2JOYSTICKS        80
-#define LW_LANG_STRING_CONTROLS_4BUTTONS          81
-#define LW_LANG_STRING_CONTROLS_STANDARD          82
-#define LW_LANG_STRING_CONTROLS_MOUSESENSIB       83
+#define LW_LANG_STRING_CONTROLS_JOYSTICK          81
+#define LW_LANG_STRING_CONTROLS_OFF               82
+#define LW_LANG_STRING_CONTROLS_2JOYSTICKS        83
+#define LW_LANG_STRING_CONTROLS_4BUTTONS          84
+#define LW_LANG_STRING_CONTROLS_STANDARD          85
+#define LW_LANG_STRING_CONTROLS_MOUSESENSIB       86
 
-#define LW_LANG_STRING_ABOUT_CREDITS              84
-#define LW_LANG_STRING_ABOUT_COPYRIGHT            85
-#define LW_LANG_STRING_ABOUT_LICENSE              86
-#define LW_LANG_STRING_ABOUT_VERSION              87
+#define LW_LANG_STRING_ABOUT_CREDITS              87
+#define LW_LANG_STRING_ABOUT_COPYRIGHT            88
+#define LW_LANG_STRING_ABOUT_LICENSE              89
+#define LW_LANG_STRING_ABOUT_VERSION              90
 
-#define LW_LANG_STRING_INTERNET_REFRESH           88
-#define LW_LANG_STRING_INTERNET_JOINNOW           89
-#define LW_LANG_STRING_INTERNET_PORT              90
-#define LW_LANG_STRING_INTERNET_PASSWORD          91
-#define LW_LANG_STRING_INTERNET_YES               92
-#define LW_LANG_STRING_INTERNET_NO                93
-#define LW_LANG_STRING_INTERNET_UPTIME            94
-#define LW_LANG_STRING_INTERNET_DAYS              95
-#define LW_LANG_STRING_INTERNET_DAY               96
-#define LW_LANG_STRING_INTERNET_HOURS             97
-#define LW_LANG_STRING_INTERNET_MINUTES           98
-#define LW_LANG_STRING_INTERNET_SECONDS           99
-#define LW_LANG_STRING_INTERNET_UNREACHABLE      100
-#define LW_LANG_STRING_INTERNET_PING             101
-#define LW_LANG_STRING_INTERNET_MSEC             102
+#define LW_LANG_STRING_INTERNET_REFRESH           91
+#define LW_LANG_STRING_INTERNET_JOINNOW           92
+#define LW_LANG_STRING_INTERNET_PORT              93
+#define LW_LANG_STRING_INTERNET_PASSWORD          94
+#define LW_LANG_STRING_INTERNET_YES               95
+#define LW_LANG_STRING_INTERNET_NO                96
+#define LW_LANG_STRING_INTERNET_UPTIME            97
+#define LW_LANG_STRING_INTERNET_DAYS              98
+#define LW_LANG_STRING_INTERNET_DAY               99
+#define LW_LANG_STRING_INTERNET_HOURS            100
+#define LW_LANG_STRING_INTERNET_MINUTES          101
+#define LW_LANG_STRING_INTERNET_SECONDS          102
+#define LW_LANG_STRING_INTERNET_UNREACHABLE      103
+#define LW_LANG_STRING_INTERNET_PING             104
+#define LW_LANG_STRING_INTERNET_MSEC             105
 
-#define LW_LANG_STRING_WAVE_AMPLI                103
-#define LW_LANG_STRING_WAVE_NUMBER               104
-#define LW_LANG_STRING_WAVE_SPEED                105
-#define LW_LANG_STRING_WAVE_WX                   106
-#define LW_LANG_STRING_WAVE_HY                   107
-#define LW_LANG_STRING_WAVE_WY                   108
-#define LW_LANG_STRING_WAVE_HX                   109
+#define LW_LANG_STRING_WAVE_AMPLI                106
+#define LW_LANG_STRING_WAVE_NUMBER               107
+#define LW_LANG_STRING_WAVE_SPEED                108
+#define LW_LANG_STRING_WAVE_WX                   109
+#define LW_LANG_STRING_WAVE_HY                   110
+#define LW_LANG_STRING_WAVE_WY                   111
+#define LW_LANG_STRING_WAVE_HX                   112
 
-#define LW_LANG_STRING_CONNECT_STARTNOW          110
-#define LW_LANG_STRING_CONNECT_WAITING           111
-#define LW_LANG_STRING_CONNECT_WAITINGFOR        112
-#define LW_LANG_STRING_CONNECT_TEAMS             113
-#define LW_LANG_STRING_CONNECT_SENDMESSAGE       114
+#define LW_LANG_STRING_CONNECT_STARTNOW          113
+#define LW_LANG_STRING_CONNECT_WAITING           114
+#define LW_LANG_STRING_CONNECT_WAITINGFOR        115
+#define LW_LANG_STRING_CONNECT_TEAMS             116
+#define LW_LANG_STRING_CONNECT_SENDMESSAGE       117
 
-#define LW_LANG_STRING_NETPLAY_CONNECT           115
-#define LW_LANG_STRING_NETPLAY_PING              116
-#define LW_LANG_STRING_NETPLAY_CHECKPROGRAM      117
-#define LW_LANG_STRING_NETPLAY_CHECKVERSION      118
-#define LW_LANG_STRING_NETPLAY_SENDPASSWORD      119
-#define LW_LANG_STRING_NETPLAY_FREETEAMS         120
-#define LW_LANG_STRING_NETPLAY_RESERVETEAMS      121
-#define LW_LANG_STRING_NETPLAY_SENDCONFIG        122
-#define LW_LANG_STRING_NETPLAY_SENDMAP           123
-#define LW_LANG_STRING_NETPLAY_WAITING           124
-#define LW_LANG_STRING_NETPLAY_WHOPLAYS          125
-#define LW_LANG_STRING_NETPLAY_RECVCONFIG        126
-#define LW_LANG_STRING_NETPLAY_RECVMAP           127
+#define LW_LANG_STRING_NETPLAY_CONNECT           118
+#define LW_LANG_STRING_NETPLAY_PING              119
+#define LW_LANG_STRING_NETPLAY_CHECKPROGRAM      120
+#define LW_LANG_STRING_NETPLAY_CHECKVERSION      121
+#define LW_LANG_STRING_NETPLAY_SENDPASSWORD      122
+#define LW_LANG_STRING_NETPLAY_FREETEAMS         123
+#define LW_LANG_STRING_NETPLAY_RESERVETEAMS      124
+#define LW_LANG_STRING_NETPLAY_SENDCONFIG        125
+#define LW_LANG_STRING_NETPLAY_SENDMAP           126
+#define LW_LANG_STRING_NETPLAY_WAITING           127
+#define LW_LANG_STRING_NETPLAY_WHOPLAYS          128
+#define LW_LANG_STRING_NETPLAY_RECVCONFIG        129
+#define LW_LANG_STRING_NETPLAY_RECVMAP           130
 
-#define LW_LANG_STRING_LEVEL_USEDEFAULTTEXTURE   128
-#define LW_LANG_STRING_LEVEL_ON                  129
-#define LW_LANG_STRING_LEVEL_OFF                 130
-#define LW_LANG_STRING_LEVEL_RANDOMMAP           131
+#define LW_LANG_STRING_LEVEL_USEDEFAULTTEXTURE   131
+#define LW_LANG_STRING_LEVEL_ON                  132
+#define LW_LANG_STRING_LEVEL_OFF                 133
+#define LW_LANG_STRING_LEVEL_RANDOMMAP           134
 
-#define LW_LANG_STRING_CODE_FPS                  132
-#define LW_LANG_STRING_CODE_RPS                  133
-#define LW_LANG_STRING_CODE_PERCENTCALC          134
-#define LW_LANG_STRING_CODE_PERCENTDISPLAY       135
-#define LW_LANG_STRING_CODE_SPREADGRADTIME       136
-#define LW_LANG_STRING_CODE_MOVEARMYTIME         137
-#define LW_LANG_STRING_CODE_DISPLAYTIME          138
-#define LW_LANG_STRING_CODE_FLIPTIME             139
-#define LW_LANG_STRING_CODE_OTHERCALCTIME        140
-#define LW_LANG_STRING_CODE_GLOBALTIME           141
-#define LW_LANG_STRING_CODE_STANDARDDISPLAY      142
-#define LW_LANG_STRING_CODE_GRADIENT1            143
-#define LW_LANG_STRING_CODE_GRADIENT2            144
-#define LW_LANG_STRING_CODE_GRADIENT3            145
-#define LW_LANG_STRING_CODE_GRADIENT4            146
-#define LW_LANG_STRING_CODE_GRADIENT5            147
-#define LW_LANG_STRING_CODE_GRADIENT6            148
-#define LW_LANG_STRING_CODE_MESHSIZE             149
-#define LW_LANG_STRING_CODE_MESHSTRUCTURE        150
-#define LW_LANG_STRING_CODE_PAUSEOFF             151
-#define LW_LANG_STRING_CODE_PAUSEON              152
-#define LW_LANG_STRING_CODE_WAVEEFFECTSOFF       153
-#define LW_LANG_STRING_CODE_WAVEEFFECTSON        154
-#define LW_LANG_STRING_CODE_CAPTUREOFF           155
-#define LW_LANG_STRING_CODE_CAPTUREON            156
+#define LW_LANG_STRING_CODE_FPS                  135
+#define LW_LANG_STRING_CODE_RPS                  136
+#define LW_LANG_STRING_CODE_PERCENTCALC          137
+#define LW_LANG_STRING_CODE_PERCENTDISPLAY       138
+#define LW_LANG_STRING_CODE_SPREADGRADTIME       139
+#define LW_LANG_STRING_CODE_MOVEARMYTIME         140
+#define LW_LANG_STRING_CODE_DISPLAYTIME          141
+#define LW_LANG_STRING_CODE_FLIPTIME             142
+#define LW_LANG_STRING_CODE_OTHERCALCTIME        143
+#define LW_LANG_STRING_CODE_GLOBALTIME           144
+#define LW_LANG_STRING_CODE_STANDARDDISPLAY      145
+#define LW_LANG_STRING_CODE_GRADIENT1            146
+#define LW_LANG_STRING_CODE_GRADIENT2            147
+#define LW_LANG_STRING_CODE_GRADIENT3            148
+#define LW_LANG_STRING_CODE_GRADIENT4            149
+#define LW_LANG_STRING_CODE_GRADIENT5            150
+#define LW_LANG_STRING_CODE_GRADIENT6            151
+#define LW_LANG_STRING_CODE_MESHSIZE             152
+#define LW_LANG_STRING_CODE_MESHSTRUCTURE        153
+#define LW_LANG_STRING_CODE_PAUSEOFF             154
+#define LW_LANG_STRING_CODE_PAUSEON              155
+#define LW_LANG_STRING_CODE_WAVEEFFECTSOFF       156
+#define LW_LANG_STRING_CODE_WAVEEFFECTSON        157
+#define LW_LANG_STRING_CODE_CAPTUREOFF           158
+#define LW_LANG_STRING_CODE_CAPTUREON            159
 
-#define LW_LANG_STRING_SCORE_WINNER              157
+#define LW_LANG_STRING_SCORE_WINNER              160
 
-#define LW_LANG_STRING_GAME_BACKMEMFAIL          158
-#define LW_LANG_STRING_GAME_DISPMEMFAIL          159
-#define LW_LANG_STRING_GAME_MESHMEMFAIL          160
-#define LW_LANG_STRING_GAME_AREAMEMFAIL          161
-#define LW_LANG_STRING_GAME_ARMYMEMFAIL          162
+#define LW_LANG_STRING_GAME_BACKMEMFAIL          161
+#define LW_LANG_STRING_GAME_DISPMEMFAIL          162
+#define LW_LANG_STRING_GAME_MESHMEMFAIL          163
+#define LW_LANG_STRING_GAME_AREAMEMFAIL          164
+#define LW_LANG_STRING_GAME_ARMYMEMFAIL          165
 
-#define LW_LANG_STRING_ERROR_NOTENOUGHTEAMS      163
-#define LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA    164
-#define LW_LANG_STRING_ERROR_GRAPHICSINITFAILED  165
-#define LW_LANG_STRING_ERROR_NONETWORKSUPPORT    166
-#define LW_LANG_STRING_ERROR_UNABLETOCONNECT     167
-#define LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER 168
-#define LW_LANG_STRING_ERROR_WRONGVERSION        169
-#define LW_LANG_STRING_ERROR_NETWORKPROBLEM      170
-#define LW_LANG_STRING_ERROR_CANTSENDMAP         171
-#define LW_LANG_STRING_ERROR_CANTRECEIVEMAP      172
-#define LW_LANG_STRING_ERROR_SERVERFULL          173
-#define LW_LANG_STRING_ERROR_BADPASSWORD         174
-#define LW_LANG_STRING_ERROR_BADCONFIGRANGE      175
+#define LW_LANG_STRING_ERROR_NOTENOUGHTEAMS      166
+#define LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA    167
+#define LW_LANG_STRING_ERROR_GRAPHICSINITFAILED  168
+#define LW_LANG_STRING_ERROR_NONETWORKSUPPORT    169
+#define LW_LANG_STRING_ERROR_UNABLETOCONNECT     170
+#define LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER 171
+#define LW_LANG_STRING_ERROR_WRONGVERSION        172
+#define LW_LANG_STRING_ERROR_NETWORKPROBLEM      173
+#define LW_LANG_STRING_ERROR_CANTSENDMAP         174
+#define LW_LANG_STRING_ERROR_CANTRECEIVEMAP      175
+#define LW_LANG_STRING_ERROR_SERVERFULL          176
+#define LW_LANG_STRING_ERROR_BADPASSWORD         177
+#define LW_LANG_STRING_ERROR_BADCONFIGRANGE      178
 
-#define LW_LANG_STRING_POPUP_INITFAIL            176
-#define LW_LANG_STRING_POPUP_MEMTROUBLE          177
-#define LW_LANG_STRING_POPUP_BIGDATA             178
-#define LW_LANG_STRING_POPUP_LOADFAIL            179
-#define LW_LANG_STRING_POPUP_CUSTOMFAIL          180
-#define LW_LANG_STRING_POPUP_GRAPHICSFAIL        181
+#define LW_LANG_STRING_POPUP_INITFAIL            179
+#define LW_LANG_STRING_POPUP_MEMTROUBLE          180
+#define LW_LANG_STRING_POPUP_BIGDATA             181
+#define LW_LANG_STRING_POPUP_LOADFAIL            182
+#define LW_LANG_STRING_POPUP_CUSTOMFAIL          183
+#define LW_LANG_STRING_POPUP_GRAPHICSFAIL        184
 
-#define LW_LANG_NB_STRINGS                       182
+#define LW_LANG_NB_STRINGS                       185
 
 /*==================================================================*/
 /* globals                                                          */
