@@ -72,6 +72,11 @@
 
 #define LW_RANDOM_RUN_DELAY 100
 #define LW_RANDOM_RUN_RETRIES 50
+#ifdef UNIX
+#define LW_RANDOM_COMMAND_END " > /dev/null 2>&1"
+#else
+#define LW_RANDOM_COMMAND_END ""
+#endif
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -105,61 +110,6 @@ generate_bw_palette (PALETTE pal)
     }
 }
 
-/*------------------------------------------------------------------*/
-static void
-query_min_max_map_res (int *min_w, int *min_h, int *max_w, int *max_h)
-{
-  int i;
-  int w, h;
-
-  *min_w = 2 << 24;
-  *min_h = 2 << 24;
-  *max_w = 0;
-  *max_h = 0;
-
-  for (i = 0; i < RAW_MAP_NUMBER; ++i)
-    {
-      lw_map_get_res (i, &w, &h, 0, 0, 0, 0);
-      if (*min_w > w)
-	{
-	  *min_w = w;
-	}
-      if (*min_h > h)
-	{
-	  *min_h = h;
-	}
-      if (*max_w < w)
-	{
-	  *max_w = w;
-	}
-      if (*max_h < h)
-	{
-	  *max_h = h;
-	}
-    }
-
-  if (*min_w < MIN_MAP_RES_W[CONFIG_MIN_MAP_RES])
-    {
-      *min_w = MIN_MAP_RES_W[CONFIG_MIN_MAP_RES];
-    }
-
-  if (*min_h < MIN_MAP_RES_H[CONFIG_MIN_MAP_RES])
-    {
-      *min_h = MIN_MAP_RES_H[CONFIG_MIN_MAP_RES];
-    }
-
-  if (*max_w - *min_w < 10)
-    {
-      *min_w = MIN_MAP_RES_W[2];
-      *min_h = MIN_MAP_RES_H[2];
-    }
-  if (*max_h - *min_h < 10)
-    {
-      *max_w = MIN_MAP_RES_W[6];
-      *max_h = MIN_MAP_RES_H[6];
-    }
-}
-
 /*------------------------------------------------------------------*/
 static BITMAP *
 generate_bitmap ()
@@ -170,20 +120,15 @@ generate_bitmap ()
   char filename[LW_STARTUP_MAX_PATH_LENGTH];
   char command[LW_STARTUP_MAX_PATH_LENGTH];
 
-  int min_w, min_h, max_w, max_h;
-  int width, height;
+  int size;
   int ok = 0;
 
-  query_min_max_map_res (&min_w, &min_h, &max_w, &max_h);
-  width =
-    min_w +
-    ((((random () % 10) * (random () % 10)) % 100) * (max_w - min_w)) / 100;
-  height = (width * (100 + (random () % 100))) / 200;
+  size = random () % 6;
 
   LW_MACRO_SPRINTF1 (filename, "%s.bmp", tmpnam (NULL));
   LW_MACRO_SPRINTF4 (command,
-		     "%s --out %s --width %d --height %d > /dev/null",
-		     STARTUP_GEN_PATH, filename, width, height);
+		     "%s --out %s --size %d%s",
+		     STARTUP_GEN_PATH, filename, size, LW_RANDOM_COMMAND_END);
 
   log_print_str ("Generating random map with command: \"");
   log_print_str (command);
@@ -225,7 +170,7 @@ generate_bitmap ()
      * "a little more" just to be sure.
      */
     int i;
-    
+
     for (i = 0; i < LW_RANDOM_RUN_RETRIES && exists (filename); ++i)
       {
 	rest (LW_RANDOM_RUN_DELAY);
