@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2003 Christian Mauduit                                 */
+/* Copyright (C) 1998-2004 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -189,6 +189,9 @@ lw_sock_send_str_ex (int sock, char *str)
   int res;
   int total_sent;
   int sent;
+#ifdef WIN32
+  int winerr;
+#endif
 
   if (sock >= 0)
     {
@@ -221,10 +224,18 @@ lw_sock_send_str_ex (int sock, char *str)
 	  switch (res)
 	    {
 	    case -1:
-	      if (errno != EINTR)
+#ifdef WIN32
+	      winerr = WSAGetLastError ();
+	      if (winerr != WSAEINTR && winerr != WSAENOBUFS)
 		{
 		  result = 0;
 		}
+#else
+	      if (errno != EINTR && errno != ENOBUFS)
+		{
+		  result = 0;
+		}
+#endif
 	      break;
 	    case 1:
 	      if (FD_ISSET (sock, &write))
@@ -297,6 +308,9 @@ lw_sock_recv_str_ex (int sock, char *str)
   fd_set read;
   struct timeval tv;
   int res;
+#ifdef WIN32
+  int winerr;
+#endif
 
   str[0] = '\0';
 
@@ -325,10 +339,18 @@ lw_sock_recv_str_ex (int sock, char *str)
 	  switch (res)
 	    {
 	    case -1:
+#ifdef WIN32
+	      winerr = WSAGetLastError ();
+	      if (winerr != WSAEINTR)
+		{
+		  result = 0;
+		}
+#else
 	      if (errno != EINTR)
 		{
 		  result = 0;
 		}
+#endif
 	      break;
 	    case 1:
 	      /*
@@ -464,6 +486,9 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
   int res;
   int total_sent;
   int sent;
+#ifdef WIN32
+  int winerr;
+#endif
 
   if (sock >= 0)
     {
@@ -485,10 +510,18 @@ lw_sock_send_buffer_ex (int sock, char *buffer, int len)
 	      switch (res)
 		{
 		case -1:
-		  if (errno != EINTR)
+#ifdef WIN32
+		  winerr = WSAGetLastError ();
+		  if (winerr != WSAEINTR && winerr != WSAENOBUFS)
 		    {
 		      result = 0;
 		    }
+#else
+		  if (errno != EINTR && errno != ENOBUFS)
+		    {
+		      result = 0;
+		    }
+#endif
 		  break;
 		case 1:
 		  if (FD_ISSET (sock, &write))
@@ -564,6 +597,9 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
   struct timeval tv;
   int total_received;
   int received;
+#ifdef WIN32
+  int winerr;
+#endif
 
   memset (buffer, 0, len);
 
@@ -587,10 +623,18 @@ lw_sock_recv_buffer_ex (int sock, char *buffer, int len)
 	      switch (res)
 		{
 		case -1:
+#ifdef WIN32
+		  winerr = WSAGetLastError ();
+		  if (winerr != WSAEINTR)
+		    {
+		      result = 0;
+		    }
+#else
 		  if (errno != EINTR)
 		    {
 		      result = 0;
 		    }
+#endif
 		  break;
 		case 1:
 		  if (FD_ISSET (sock, &read))
